@@ -14,4 +14,5 @@ from .imap_server import QIMAPServer
 from .redis_server import QRedisServer
 from .mysql_server import QMysqlServer
 from .vnc_server import QVNCServer
-from .helper import server_arguments,clean_all,kill_servers, get_free_port, close_port_wrapper, kill_server_wrapper, setup_logger, disable_logger
+from .qbsniffer import QBSniffer
+from .helper import server_arguments,clean_all,kill_servers, get_free_port, close_port_wrapper, kill_server_wrapper, setup_logger, disable_logger, postgres_class
\ No newline at end of file
